:github_url: https://github.com/tasts-robots/pink/tree/master/doc/src/joint-limits.rst

.. _Joint limits:

************
Joint limits
************

[Until this section is written, you can check out this former version: `inequality constraints <https://scaron.info/robot-locomotion/inverse-kinematics.html#inequality-constraints>`_.]

.. automodule:: pink.limits
    :members:
